@@ -1,19 +1,8 @@
-/********************************************************************
-Copyright © 2019 Roman Gilg <subdiff@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2019 Roman Gilg <subdiff@gmail.com>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #pragma once
 
 #include <kscreen/config.h>
@@ -51,6 +40,7 @@ public:
         CapabilitiesRole,
         OverscanRole,
         VrrPolicyRole,
+        RgbRangeRole,
     };
 
     explicit OutputModel(ConfigHandler *configHandler);
@@ -111,6 +101,8 @@ private:
     };
 
     void roleChanged(int outputId, OutputRoles role);
+    void rolesChanged(int outputId, const QVector<int> &roles);
+    QModelIndex indexForOutputId(int outputId) const;
 
     void resetPosition(const Output &output);
     void reposition();
